@@ -33,15 +33,13 @@
 #include <QTimer>
 
 #include <QDateTime>
-#include <QDebug>
 #include <QDir>
 #include <QStandardPaths>
 
 class Akregator::Backend::StorageMK4Impl::StorageMK4ImplPrivate
 {
 public:
-    StorageMK4ImplPrivate() : modified(false)
-        , purl("url")
+    StorageMK4ImplPrivate() : purl("url")
         , pFeedList("feedList")
         , punread("unread")
         , ptotalCount("totalCount")
@@ -52,8 +50,8 @@ public:
     c4_Storage *storage;
     Akregator::Backend::StorageMK4Impl *q;
     c4_View archiveView;
-    bool autoCommit;
-    bool modified;
+    bool autoCommit = false;
+    bool modified = false;
     mutable QMap<QString, Akregator::Backend::FeedStorageMK4Impl *> feeds;
     QStringList feedURLs;
     c4_StringProp purl, pFeedList;
@@ -126,7 +124,7 @@ Akregator::Backend::StorageMK4Impl::~StorageMK4Impl()
 {
     close();
     delete d;
-    d = 0;
+    d = nullptr;
 }
 
 void Akregator::Backend::StorageMK4Impl::initialize(const QStringList &)
@@ -294,7 +292,8 @@ QStringList Akregator::Backend::StorageMK4Impl::feeds() const
 {
     // TODO: cache list
     QStringList list;
-    int size = d->archiveView.GetSize();
+    const int size = d->archiveView.GetSize();
+    list.reserve(size);
     for (int i = 0; i < size; ++i) {
         list += QString::fromLatin1(d->purl(d->archiveView.GetAt(i)));
     }
