@@ -26,7 +26,6 @@
 #include "akregatorconfig.h"
 #include "actions/actions.h"
 #include "urlhandler/webengine/urlhandlerwebengine.h"
-#include <QtWebEngineWidgetsVersion>
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
 #include <KPIMTextEdit/TextToSpeech>
@@ -47,6 +46,7 @@
 #include <viewerplugintoolmanager.h>
 #include <QWebEngineProfile>
 #include <QWebEngineUrlRequestInterceptor>
+#include <QtWebEngineWidgetsVersion>
 
 #include <WebEngineViewer/WebHitTestResult>
 #include <WebEngineViewer/WebHitTest>
@@ -81,8 +81,8 @@ ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *p
 {
     mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
 
-    QWebEngineProfile *profile = QWebEngineProfile::defaultProfile();
-    mPageEngine = new ArticleViewerWebEnginePage(profile, this);
+    mPageEngine = new ArticleViewerWebEnginePage(this);
+    QWebEngineProfile *profile = mPageEngine->profile();
     profile->setPersistentCookiesPolicy(QWebEngineProfile::ForcePersistentCookies);
 
     // Needed to workaround crash in webengine, see https://bugreports.qt.io/browse/QTBUG-72260
