@@ -80,51 +80,50 @@ class Q_DECL_HIDDEN Akregator::Feed::Private
 public:
     explicit Private(Backend::Storage *storage, Akregator::Feed *qq);
 
-    Backend::Storage *storage = nullptr;
-    bool autoFetch = false;
-    int fetchInterval;
-    ArchiveMode archiveMode;
-    int maxArticleAge;
-    int maxArticleNumber;
-    bool markImmediatelyAsRead = false;
-    bool useNotification = false;
-    bool loadLinkedWebsite = false;
-    int lastFetched;
+    Backend::Storage *m_storage = nullptr;
+    bool m_autoFetch = false;
+    int m_fetchInterval;
+    ArchiveMode m_archiveMode;
+    int m_maxArticleAge;
+    int m_maxArticleNumber;
+    bool m_markImmediatelyAsRead = false;
+    bool m_useNotification = false;
+    bool m_loadLinkedWebsite = false;
 
-    Syndication::ErrorCode fetchErrorCode;
-    int fetchTries;
-    bool followDiscovery = false;
-    Syndication::Loader *loader = nullptr;
-    bool articlesLoaded = false;
-    Backend::FeedStorage *archive = nullptr;
+    Syndication::ErrorCode m_fetchErrorCode;
+    int m_fetchTries;
+    bool m_followDiscovery = false;
+    Syndication::Loader *m_loader = nullptr;
+    bool m_articlesLoaded = false;
+    Backend::FeedStorage *m_archive = nullptr;
 
-    QString xmlUrl;
-    QString htmlUrl;
-    QString description;
+    QString m_xmlUrl;
+    QString m_htmlUrl;
+    QString m_description;
+    QString m_comment;
 
     /** list of feed articles */
     QHash<QString, Article> articles;
 
     /** list of deleted articles. This contains **/
-    QVector<Article> deletedArticles;
+    QVector<Article> m_deletedArticles;
 
     /** caches guids of deleted articles for notification */
 
-    QVector<Article> addedArticlesNotify;
-    QVector<Article> removedArticlesNotify;
-    QVector<Article> updatedArticlesNotify;
+    QVector<Article> m_addedArticlesNotify;
+    QVector<Article> m_removedArticlesNotify;
+    QVector<Article> m_updatedArticlesNotify;
 
-    QPixmap imagePixmap;
-    Syndication::ImagePtr image;
-    QIcon favicon;
-    mutable int totalCount;
+    QPixmap m_imagePixmap;
+    QIcon m_favicon;
+    mutable int m_totalCount;
     void setTotalCountDirty() const
     {
-        totalCount = -1;
+        m_totalCount = -1;
     }
 };
 
-QString Akregator::Feed::archiveModeToString(ArchiveMode mode)
+QString Feed::archiveModeToString(ArchiveMode mode)
 {
     switch (mode) {
     case keepAllArticles:
@@ -141,13 +140,13 @@ QString Akregator::Feed::archiveModeToString(ArchiveMode mode)
     return QStringLiteral("globalDefault");
 }
 
-Akregator::Feed *Akregator::Feed::fromOPML(QDomElement e, Backend::Storage *storage)
+Akregator::Feed *Feed::fromOPML(const QDomElement &e, Backend::Storage *storage)
 {
     if (!e.hasAttribute(QStringLiteral("xmlUrl")) && !e.hasAttribute(QStringLiteral("xmlurl")) && !e.hasAttribute(QStringLiteral("xmlURL"))) {
         return nullptr;
     }
 
-    QString title = e.hasAttribute(QStringLiteral("text")) ? e.attribute(QStringLiteral("text")) : e.attribute(QStringLiteral("title"));
+    const QString title = e.hasAttribute(QStringLiteral("text")) ? e.attribute(QStringLiteral("text")) : e.attribute(QStringLiteral("title"));
 
     QString xmlUrl = e.hasAttribute(QStringLiteral("xmlUrl")) ? e.attribute(QStringLiteral("xmlUrl")) : e.attribute(QStringLiteral("xmlurl"));
     if (xmlUrl.isEmpty()) {
@@ -156,16 +155,17 @@ Akregator::Feed *Akregator::Feed::fromOPML(QDomElement e, Backend::Storage *stor
 
     bool useCustomFetchInterval = e.attribute(QStringLiteral("useCustomFetchInterval")) == QLatin1String("true");
 
-    QString htmlUrl = e.attribute(QStringLiteral("htmlUrl"));
-    QString description = e.attribute(QStringLiteral("description"));
-    int fetchInterval = e.attribute(QStringLiteral("fetchInterval")).toInt();
-    ArchiveMode archiveMode = stringToArchiveMode(e.attribute(QStringLiteral("archiveMode")));
-    int maxArticleAge = e.attribute(QStringLiteral("maxArticleAge")).toUInt();
-    int maxArticleNumber = e.attribute(QStringLiteral("maxArticleNumber")).toUInt();
-    bool markImmediatelyAsRead = e.attribute(QStringLiteral("markImmediatelyAsRead")) == QLatin1String("true");
-    bool useNotification = e.attribute(QStringLiteral("useNotification")) == QLatin1String("true");
-    bool loadLinkedWebsite = e.attribute(QStringLiteral("loadLinkedWebsite")) == QLatin1String("true");
-    uint id = e.attribute(QStringLiteral("id")).toUInt();
+    const QString htmlUrl = e.attribute(QStringLiteral("htmlUrl"));
+    const QString description = e.attribute(QStringLiteral("description"));
+    const int fetchInterval = e.attribute(QStringLiteral("fetchInterval")).toInt();
+    const ArchiveMode archiveMode = stringToArchiveMode(e.attribute(QStringLiteral("archiveMode")));
+    const int maxArticleAge = e.attribute(QStringLiteral("maxArticleAge")).toUInt();
+    const int maxArticleNumber = e.attribute(QStringLiteral("maxArticleNumber")).toUInt();
+    const bool markImmediatelyAsRead = e.attribute(QStringLiteral("markImmediatelyAsRead")) == QLatin1String("true");
+    const bool useNotification = e.attribute(QStringLiteral("useNotification")) == QLatin1String("true");
+    const bool loadLinkedWebsite = e.attribute(QStringLiteral("loadLinkedWebsite")) == QLatin1String("true");
+    const QString comment = e.attribute(QStringLiteral("comment"));
+    const uint id = e.attribute(QStringLiteral("id")).toUInt();
 
     Feed *const feed = new Feed(storage);
     feed->setTitle(title);
@@ -181,16 +181,16 @@ Akregator::Feed *Akregator::Feed::fromOPML(QDomElement e, Backend::Storage *stor
     feed->setMaxArticleNumber(maxArticleNumber);
     feed->setMarkImmediatelyAsRead(markImmediatelyAsRead);
     feed->setLoadLinkedWebsite(loadLinkedWebsite);
-
-    if (!feed->d->archive && storage) {
+    feed->setComment(comment);
+    if (!feed->d->m_archive && storage) {
         // Instead of loading the articles, we use the cache from storage
-        feed->d->archive = storage->archiveFor(xmlUrl);
-        feed->d->totalCount = feed->d->archive->totalCount();
+        feed->d->m_archive = storage->archiveFor(xmlUrl);
+        feed->d->m_totalCount = feed->d->m_archive->totalCount();
     }
     return feed;
 }
 
-bool Akregator::Feed::accept(TreeNodeVisitor *visitor)
+bool Feed::accept(TreeNodeVisitor *visitor)
 {
     if (visitor->visitFeed(this)) {
         return true;
@@ -199,79 +199,79 @@ bool Akregator::Feed::accept(TreeNodeVisitor *visitor)
     }
 }
 
-QVector<const Folder *> Akregator::Feed::folders() const
+QVector<const Folder *> Feed::folders() const
 {
     return QVector<const Folder *>();
 }
 
-QVector<Folder *> Akregator::Feed::folders()
+QVector<Folder *> Feed::folders()
 {
     return QVector<Folder *>();
 }
 
-QVector<const Akregator::Feed *> Akregator::Feed::feeds() const
+QVector<const Akregator::Feed *> Feed::feeds() const
 {
     QVector<const Akregator::Feed *> list;
     list.append(this);
     return list;
 }
 
-QVector<Akregator::Feed *> Akregator::Feed::feeds()
+QVector<Akregator::Feed *> Feed::feeds()
 {
     QVector<Feed *> list;
     list.append(this);
     return list;
 }
 
-Article Akregator::Feed::findArticle(const QString &guid) const
+Article Feed::findArticle(const QString &guid) const
 {
     return d->articles.value(guid);
 }
 
-QVector<Article> Akregator::Feed::articles()
+QVector<Article> Feed::articles()
 {
-    if (!d->articlesLoaded) {
+    if (!d->m_articlesLoaded) {
         loadArticles();
     }
     return valuesToVector(d->articles);
 }
 
-Backend::Storage *Akregator::Feed::storage()
+Backend::Storage *Feed::storage()
 {
-    return d->storage;
+    return d->m_storage;
 }
 
-void Akregator::Feed::loadArticles()
+void Feed::loadArticles()
 {
-    if (d->articlesLoaded) {
+    if (d->m_articlesLoaded) {
         return;
     }
 
-    if (!d->archive && d->storage) {
-        d->archive = d->storage->archiveFor(xmlUrl());
+    if (!d->m_archive && d->m_storage) {
+        d->m_archive = d->m_storage->archiveFor(xmlUrl());
     }
 
-    QStringList list = d->archive->articles();
+    QStringList list = d->m_archive->articles();
     for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); ++it) {
-        Article mya(*it, this, d->archive);
+        Article mya(*it, this, d->m_archive);
         d->articles[mya.guid()] = mya;
         if (mya.isDeleted()) {
-            d->deletedArticles.append(mya);
+            d->m_deletedArticles.append(mya);
         }
     }
 
-    d->articlesLoaded = true;
+    d->m_articlesLoaded = true;
     enforceLimitArticleNumber();
     recalcUnreadCount();
 }
 
-void Akregator::Feed::recalcUnreadCount()
+void Feed::recalcUnreadCount()
 {
     QVector<Article> tarticles = articles();
     QVector<Article>::ConstIterator it;
     QVector<Article>::ConstIterator en = tarticles.constEnd();
 
-    int oldUnread = d->archive->unread();
+    int oldUnread = d->m_archive->unread();
 
     int unread = 0;
 
@@ -282,12 +282,12 @@ void Akregator::Feed::recalcUnreadCount()
     }
 
     if (unread != oldUnread) {
-        d->archive->setUnread(unread);
+        d->m_archive->setUnread(unread);
         nodeModified();
     }
 }
 
-Akregator::Feed::ArchiveMode Akregator::Feed::stringToArchiveMode(const QString &str)
+Feed::ArchiveMode Feed::stringToArchiveMode(const QString &str)
 {
     if (str == QLatin1String("globalDefault")) {
         return globalDefault;
@@ -304,36 +304,35 @@ Akregator::Feed::ArchiveMode Akregator::Feed::stringToArchiveMode(const QString
     return globalDefault;
 }
 
-Akregator::Feed::Private::Private(Backend::Storage *storage_, Akregator::Feed *qq)
+Feed::Private::Private(Backend::Storage *storage_, Akregator::Feed *qq)
     : q(qq)
-    , storage(storage_)
-    , autoFetch(false)
-    , fetchInterval(30)
-    , archiveMode(globalDefault)
-    , maxArticleAge(60)
-    , maxArticleNumber(1000)
-    , markImmediatelyAsRead(false)
-    , useNotification(false)
-    , loadLinkedWebsite(false)
-    , lastFetched(0)
-    , fetchErrorCode(Syndication::Success)
-    , fetchTries(0)
-    , followDiscovery(false)
-    , loader(nullptr)
-    , articlesLoaded(false)
-    , archive(nullptr)
-    , totalCount(-1)
+    , m_storage(storage_)
+    , m_autoFetch(false)
+    , m_fetchInterval(30)
+    , m_archiveMode(globalDefault)
+    , m_maxArticleAge(60)
+    , m_maxArticleNumber(1000)
+    , m_markImmediatelyAsRead(false)
+    , m_useNotification(false)
+    , m_loadLinkedWebsite(false)
+    , m_fetchErrorCode(Syndication::Success)
+    , m_fetchTries(0)
+    , m_followDiscovery(false)
+    , m_loader(nullptr)
+    , m_articlesLoaded(false)
+    , m_archive(nullptr)
+    , m_totalCount(-1)
 {
     Q_ASSERT(q);
-    Q_ASSERT(storage);
+    Q_ASSERT(m_storage);
 }
 
-Akregator::Feed::Feed(Backend::Storage *storage) : TreeNode()
+Feed::Feed(Backend::Storage *storage) : TreeNode()
     , d(new Private(storage, this))
 {
 }
 
-Akregator::Feed::~Feed()
+Feed::~Feed()
 {
     slotAbortFetch();
     emitSignalDestroyed();
@@ -341,7 +340,7 @@ Akregator::Feed::~Feed()
     d = nullptr;
 }
 
-void Akregator::Feed::loadFavicon(const QUrl &url)
+void Feed::loadFavicon(const QUrl &url)
 {
     KIO::FavIconRequestJob *job = new KIO::FavIconRequestJob(url);
     connect(job, &KIO::FavIconRequestJob::result, this, [job, this](KJob *) {
@@ -351,175 +350,187 @@ void Akregator::Feed::loadFavicon(const QUrl &url)
     });
 }
 
-bool Akregator::Feed::useCustomFetchInterval() const
+bool Feed::useCustomFetchInterval() const
 {
-    return d->autoFetch;
+    return d->m_autoFetch;
 }
 
-void Akregator::Feed::setCustomFetchIntervalEnabled(bool enabled)
+void Feed::setCustomFetchIntervalEnabled(bool enabled)
 {
-    d->autoFetch = enabled;
+    d->m_autoFetch = enabled;
 }
 
-int Akregator::Feed::fetchInterval() const
+int Feed::fetchInterval() const
 {
-    return d->fetchInterval;
+    return d->m_fetchInterval;
 }
 
-void Akregator::Feed::setFetchInterval(int interval)
+void Feed::setFetchInterval(int interval)
 {
-    d->fetchInterval = interval;
+    d->m_fetchInterval = interval;
 }
 
-int Akregator::Feed::maxArticleAge() const
+int Feed::maxArticleAge() const
 {
-    return d->maxArticleAge;
+    return d->m_maxArticleAge;
 }
 
-void Akregator::Feed::setMaxArticleAge(int maxArticleAge)
+void Feed::setMaxArticleAge(int maxArticleAge)
 {
-    d->maxArticleAge = maxArticleAge;
+    d->m_maxArticleAge = maxArticleAge;
 }
 
-int Akregator::Feed::maxArticleNumber() const
+int Feed::maxArticleNumber() const
 {
-    return d->maxArticleNumber;
+    return d->m_maxArticleNumber;
 }
 
-void Akregator::Feed::setMaxArticleNumber(int maxArticleNumber)
+void Feed::setMaxArticleNumber(int maxArticleNumber)
 {
-    d->maxArticleNumber = maxArticleNumber;
+    d->m_maxArticleNumber = maxArticleNumber;
 }
 
-bool Akregator::Feed::markImmediatelyAsRead() const
+bool Feed::markImmediatelyAsRead() const
 {
-    return d->markImmediatelyAsRead;
+    return d->m_markImmediatelyAsRead;
 }
 
-bool Akregator::Feed::isFetching() const
+bool Feed::isFetching() const
 {
-    return d->loader != nullptr;
+    return d->m_loader != nullptr;
 }
 
-void Akregator::Feed::setMarkImmediatelyAsRead(bool enabled)
+void Feed::setMarkImmediatelyAsRead(bool enabled)
 {
-    d->markImmediatelyAsRead = enabled;
+    d->m_markImmediatelyAsRead = enabled;
 }
 
-void Akregator::Feed::setUseNotification(bool enabled)
+void Feed::setComment(const QString &comment)
 {
-    d->useNotification = enabled;
+    d->m_comment = comment;
 }
 
-bool Akregator::Feed::useNotification() const
+QString Feed::comment() const
 {
-    return d->useNotification;
+    return d->m_comment;
 }
 
-void Akregator::Feed::setLoadLinkedWebsite(bool enabled)
+void Feed::setUseNotification(bool enabled)
 {
-    d->loadLinkedWebsite = enabled;
+    d->m_useNotification = enabled;
 }
 
-bool Akregator::Feed::loadLinkedWebsite() const
+bool Feed::useNotification() const
 {
-    return d->loadLinkedWebsite;
+    return d->m_useNotification;
 }
 
-QPixmap Akregator::Feed::image() const
+void Feed::setLoadLinkedWebsite(bool enabled)
 {
-    return d->imagePixmap;
+    d->m_loadLinkedWebsite = enabled;
 }
 
-QString Akregator::Feed::xmlUrl() const
+bool Feed::loadLinkedWebsite() const
 {
-    return d->xmlUrl;
+    return d->m_loadLinkedWebsite;
 }
 
-void Akregator::Feed::setXmlUrl(const QString &s)
+QPixmap Feed::image() const
 {
-    d->xmlUrl = s;
+    return d->m_imagePixmap;
+}
+
+QString Feed::xmlUrl() const
+{
+    return d->m_xmlUrl;
+}
+
+void Feed::setXmlUrl(const QString &s)
+{
+    d->m_xmlUrl = s;
     if (!Settings::fetchOnStartup()) {
         QTimer::singleShot(KRandom::random() % 4000, this, &Feed::slotAddFeedIconListener);    // TODO: let's give a gui some time to show up before starting the fetch when no fetch on startup is used. replace this with something proper later...
     }
 }
 
-QString Akregator::Feed::htmlUrl() const
+QString Feed::htmlUrl() const
 {
-    return d->htmlUrl;
+    return d->m_htmlUrl;
 }
 
-void Akregator::Feed::setHtmlUrl(const QString &s)
+void Feed::setHtmlUrl(const QString &s)
 {
-    d->htmlUrl = s;
+    d->m_htmlUrl = s;
 }
 
-QString Akregator::Feed::description() const
+QString Feed::description() const
 {
-    return d->description;
+    return d->m_description;
 }
 
-void Akregator::Feed::setDescription(const QString &s)
+void Feed::setDescription(const QString &s)
 {
-    d->description = s;
+    d->m_description = s;
 }
 
-bool Akregator::Feed::fetchErrorOccurred() const
+bool Feed::fetchErrorOccurred() const
 {
-    return d->fetchErrorCode != Syndication::Success;
+    return d->m_fetchErrorCode != Syndication::Success;
 }
 
-Syndication::ErrorCode Akregator::Feed::fetchErrorCode() const
+Syndication::ErrorCode Feed::fetchErrorCode() const
 {
-    return d->fetchErrorCode;
+    return d->m_fetchErrorCode;
 }
 
-bool Akregator::Feed::isArticlesLoaded() const
+bool Feed::isArticlesLoaded() const
 {
-    return d->articlesLoaded;
+    return d->m_articlesLoaded;
 }
 
-QDomElement Akregator::Feed::toOPML(QDomElement parent, QDomDocument document) const
+QDomElement Feed::toOPML(QDomElement parent, QDomDocument document) const
 {
     QDomElement el = document.createElement(QStringLiteral("outline"));
     el.setAttribute(QStringLiteral("text"), title());
     el.setAttribute(QStringLiteral("title"), title());
-    el.setAttribute(QStringLiteral("xmlUrl"), d->xmlUrl);
-    el.setAttribute(QStringLiteral("htmlUrl"), d->htmlUrl);
+    el.setAttribute(QStringLiteral("xmlUrl"), d->m_xmlUrl);
+    el.setAttribute(QStringLiteral("htmlUrl"), d->m_htmlUrl);
     el.setAttribute(QStringLiteral("id"), QString::number(id()));
-    el.setAttribute(QStringLiteral("description"), d->description);
+    el.setAttribute(QStringLiteral("description"), d->m_description);
     el.setAttribute(QStringLiteral("useCustomFetchInterval"), (useCustomFetchInterval() ? QStringLiteral("true") : QStringLiteral("false")));
     el.setAttribute(QStringLiteral("fetchInterval"), QString::number(fetchInterval()));
-    el.setAttribute(QStringLiteral("archiveMode"), archiveModeToString(d->archiveMode));
-    el.setAttribute(QStringLiteral("maxArticleAge"), d->maxArticleAge);
-    el.setAttribute(QStringLiteral("maxArticleNumber"), d->maxArticleNumber);
-    if (d->markImmediatelyAsRead) {
+    el.setAttribute(QStringLiteral("archiveMode"), archiveModeToString(d->m_archiveMode));
+    el.setAttribute(QStringLiteral("maxArticleAge"), d->m_maxArticleAge);
+    el.setAttribute(QStringLiteral("comment"), d->m_comment);
+    el.setAttribute(QStringLiteral("maxArticleNumber"), d->m_maxArticleNumber);
+    if (d->m_markImmediatelyAsRead) {
         el.setAttribute(QStringLiteral("markImmediatelyAsRead"), QStringLiteral("true"));
     }
-    if (d->useNotification) {
+    if (d->m_useNotification) {
         el.setAttribute(QStringLiteral("useNotification"), QStringLiteral("true"));
     }
-    if (d->loadLinkedWebsite) {
+    if (d->m_loadLinkedWebsite) {
         el.setAttribute(QStringLiteral("loadLinkedWebsite"), QStringLiteral("true"));
     }
-    el.setAttribute(QStringLiteral("maxArticleNumber"), d->maxArticleNumber);
+    el.setAttribute(QStringLiteral("maxArticleNumber"), d->m_maxArticleNumber);
     el.setAttribute(QStringLiteral("type"), QStringLiteral("rss"));   // despite some additional fields, it is still "rss" OPML
     el.setAttribute(QStringLiteral("version"), QStringLiteral("RSS"));
     parent.appendChild(el);
     return el;
 }
 
-KJob *Akregator::Feed::createMarkAsReadJob()
+KJob *Feed::createMarkAsReadJob()
 {
     ArticleModifyJob *job = new ArticleModifyJob;
-    Q_FOREACH (const Article &i, articles()) {
+    const auto arts = articles();
+    for (const Article &i : arts) {
         const ArticleId aid = { xmlUrl(), i.guid() };
         job->setStatus(aid, Read);
     }
     return job;
 }
 
-void Akregator::Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchOnly)
+void Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchOnly)
 {
     if (!intervalFetchOnly) {
         queue->addFeed(this);
@@ -532,7 +543,7 @@ void Akregator::Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchO
             interval = Settings::autoFetchInterval() * 60;
         }
 
-        uint lastFetch = d->archive->lastFetch().toTime_t();
+        uint lastFetch = d->m_archive->lastFetch().toTime_t();
 
         uint now = QDateTime::currentDateTimeUtc().toTime_t();
 
@@ -542,12 +553,12 @@ void Akregator::Feed::slotAddToFetchQueue(FetchQueue *queue, bool intervalFetchO
     }
 }
 
-void Akregator::Feed::slotAddFeedIconListener()
+void Feed::slotAddFeedIconListener()
 {
-    loadFavicon(QUrl(d->xmlUrl));
+    loadFavicon(QUrl(d->m_xmlUrl));
 }
 
-void Akregator::Feed::appendArticles(const Syndication::FeedPtr &feed)
+void Feed::appendArticles(const Syndication::FeedPtr &feed)
 {
     d->setTotalCountDirty();
     bool changed = false;
@@ -559,7 +570,7 @@ void Akregator::Feed::appendArticles(const Syndication::FeedPtr &feed)
 
     int nudge = 0;
 
-    QVector<Article> deletedArticles = d->deletedArticles;
+    QVector<Article> deletedArticles = d->m_deletedArticles;
 
     for (; it != en; ++it) {
         if (!d->articles.contains((*it)->id())) { // article not in list
@@ -567,7 +578,7 @@ void Akregator::Feed::appendArticles(const Syndication::FeedPtr &feed)
             mya.offsetPubDate(nudge);
             nudge--;
             appendArticle(mya);
-            d->addedArticlesNotify.append(mya);
+            d->m_addedArticlesNotify.append(mya);
 
             if (!mya.isDeleted() && !markImmediatelyAsRead()) {
                 mya.setStatus(New);
@@ -592,7 +603,7 @@ void Akregator::Feed::appendArticles(const Syndication::FeedPtr &feed)
 
                 mya.setStatus(oldstatus);
 
-                d->updatedArticlesNotify.append(mya);
+                d->m_updatedArticlesNotify.append(mya);
                 changed = true;
             } else if (old.isDeleted()) {
                 deletedArticles.removeAll(mya);
@@ -609,10 +620,10 @@ void Akregator::Feed::appendArticles(const Syndication::FeedPtr &feed)
         dtmp = dit;
         ++dit;
         d->articles.remove((*dtmp).guid());
-        d->archive->deleteArticle((*dtmp).guid());
-        d->removedArticlesNotify.append(*dtmp);
+        d->m_archive->deleteArticle((*dtmp).guid());
+        d->m_removedArticlesNotify.append(*dtmp);
         changed = true;
-        d->deletedArticles.removeAll(*dtmp);
+        d->m_deletedArticles.removeAll(*dtmp);
     }
 
     if (changed) {
@@ -620,27 +631,27 @@ void Akregator::Feed::appendArticles(const Syndication::FeedPtr &feed)
     }
 }
 
-bool Akregator::Feed::usesExpiryByAge() const
+bool Feed::usesExpiryByAge() const
 {
-    return (d->archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge) || d->archiveMode == limitArticleAge;
+    return (d->m_archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge) || d->m_archiveMode == limitArticleAge;
 }
 
-bool Akregator::Feed::isExpired(const Article &a) const
+bool Feed::isExpired(const Article &a) const
 {
     QDateTime now = QDateTime::currentDateTime();
     int expiryAge = -1;
 // check whether the feed uses the global default and the default is limitArticleAge
-    if (d->archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge) {
+    if (d->m_archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge) {
         expiryAge = Settings::maxArticleAge() * 24 * 3600;
     } else // otherwise check if this feed has limitArticleAge set
-    if (d->archiveMode == limitArticleAge) {
-        expiryAge = d->maxArticleAge * 24 * 3600;
+    if (d->m_archiveMode == limitArticleAge) {
+        expiryAge = d->m_maxArticleAge * 24 * 3600;
     }
 
     return expiryAge != -1 && a.pubDate().secsTo(now) > expiryAge;
 }
 
-void Akregator::Feed::appendArticle(const Article &a)
+void Feed::appendArticle(const Article &a)
 {
     if ((a.keep() && Settings::doNotExpireImportantArticles()) || (!usesExpiryByAge() || !isExpired(a))) {   // if not expired
         if (!d->articles.contains(a.guid())) {
@@ -652,10 +663,10 @@ void Akregator::Feed::appendArticle(const Article &a)
     }
 }
 
-void Akregator::Feed::fetch(bool followDiscovery)
+void Feed::fetch(bool followDiscovery)
 {
-    d->followDiscovery = followDiscovery;
-    d->fetchTries = 0;
+    d->m_followDiscovery = followDiscovery;
+    d->m_fetchTries = 0;
 
     // mark all new as unread
     for (auto it = d->articles.begin(), end = d->articles.end(); it != end; ++it) {
@@ -669,45 +680,45 @@ void Akregator::Feed::fetch(bool followDiscovery)
     tryFetch();
 }
 
-void Akregator::Feed::slotAbortFetch()
+void Feed::slotAbortFetch()
 {
-    if (d->loader) {
-        d->loader->abort();
+    if (d->m_loader) {
+        d->m_loader->abort();
     }
 }
 
-void Akregator::Feed::tryFetch()
+void Feed::tryFetch()
 {
-    d->fetchErrorCode = Syndication::Success;
+    d->m_fetchErrorCode = Syndication::Success;
 
-    d->loader = Syndication::Loader::create(this, SLOT(fetchCompleted(Syndication::Loader*,
+    d->m_loader = Syndication::Loader::create(this, SLOT(fetchCompleted(Syndication::Loader*,
                                                                       Syndication::FeedPtr,
                                                                       Syndication::ErrorCode)));
-    d->loader->loadFrom(QUrl(d->xmlUrl), new FeedRetriever());
+    d->m_loader->loadFrom(QUrl(d->m_xmlUrl), new FeedRetriever());
 }
 
-void Akregator::Feed::slotImageFetched(const QPixmap &image)
+void Feed::slotImageFetched(const QPixmap &image)
 {
     setImage(image);
 }
 
-void Akregator::Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Syndication::ErrorCode status)
+void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Syndication::ErrorCode status)
 {
     // Note that loader instances delete themselves
-    d->loader = nullptr;
+    d->m_loader = nullptr;
 
     // fetching wasn't successful:
     if (status != Syndication::Success) {
         if (status == Syndication::Aborted) {
-            d->fetchErrorCode = Syndication::Success;
+            d->m_fetchErrorCode = Syndication::Success;
             Q_EMIT fetchAborted(this);
-        } else if (d->followDiscovery && (status == Syndication::InvalidXml) && (d->fetchTries < 3) && (l->discoveredFeedURL().isValid())) {
-            d->fetchTries++;
-            d->xmlUrl = l->discoveredFeedURL().url();
+        } else if (d->m_followDiscovery && (status == Syndication::InvalidXml) && (d->m_fetchTries < 3) && (l->discoveredFeedURL().isValid())) {
+            d->m_fetchTries++;
+            d->m_xmlUrl = l->discoveredFeedURL().url();
             Q_EMIT fetchDiscovery(this);
             tryFetch();
         } else {
-            d->fetchErrorCode = status;
+            d->m_fetchErrorCode = status;
             Q_EMIT fetchError(this);
         }
         markAsFetchedNow();
@@ -718,19 +729,19 @@ void Akregator::Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPt
 
     loadFavicon(QUrl(xmlUrl()));
 
-    d->fetchErrorCode = Syndication::Success;
+    d->m_fetchErrorCode = Syndication::Success;
 
-    if (d->imagePixmap.isNull()) {
-        const QString imageFileName = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/akregator/Media/") + Utils::fileNameForUrl(d->xmlUrl) + QLatin1String(".png");
-        d->imagePixmap = QPixmap(imageFileName, "PNG");
+    if (d->m_imagePixmap.isNull()) {
+        const QString imageFileName = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/akregator/Media/") + Utils::fileNameForUrl(d->m_xmlUrl) + QLatin1String(".png");
+        d->m_imagePixmap = QPixmap(imageFileName, "PNG");
     }
 
     if (title().isEmpty()) {
         setTitle(Syndication::htmlToPlainText(doc->title()));
     }
 
-    d->description = doc->description();
-    d->htmlUrl = doc->link();
+    d->m_description = doc->description();
+    d->m_htmlUrl = doc->link();
 
     appendArticles(doc);
 
@@ -738,23 +749,23 @@ void Akregator::Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPt
     Q_EMIT fetched(this);
 }
 
-void Akregator::Feed::markAsFetchedNow()
+void Feed::markAsFetchedNow()
 {
-    if (d->archive) {
-        d->archive->setLastFetch(QDateTime::currentDateTimeUtc());
+    if (d->m_archive) {
+        d->m_archive->setLastFetch(QDateTime::currentDateTimeUtc());
     }
 }
 
-QIcon Akregator::Feed::icon() const
+QIcon Feed::icon() const
 {
     if (fetchErrorOccurred()) {
         return QIcon::fromTheme(QStringLiteral("dialog-error"));
     }
 
-    return !d->favicon.isNull() ? d->favicon : QIcon::fromTheme(QStringLiteral("text-html"));
+    return !d->m_favicon.isNull() ? d->m_favicon : QIcon::fromTheme(QStringLiteral("text-html"));
 }
 
-void Akregator::Feed::deleteExpiredArticles(ArticleDeleteJob *deleteJob)
+void Feed::deleteExpiredArticles(ArticleDeleteJob *deleteJob)
 {
     if (!usesExpiryByAge()) {
         return;
@@ -777,60 +788,60 @@ void Akregator::Feed::deleteExpiredArticles(ArticleDeleteJob *deleteJob)
     setNotificationMode(true);
 }
 
-void Akregator::Feed::setFavicon(const QIcon &icon)
+void Feed::setFavicon(const QIcon &icon)
 {
-    d->favicon = icon;
+    d->m_favicon = icon;
     nodeModified();
 }
 
-void Akregator::Feed::setImage(const QPixmap &p)
+void Feed::setImage(const QPixmap &p)
 {
     if (p.isNull()) {
         return;
     }
-    d->imagePixmap = p;
-    const QString filename = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/akregator/Media/") + Utils::fileNameForUrl(d->xmlUrl) + QLatin1String(".png");
+    d->m_imagePixmap = p;
+    const QString filename = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/akregator/Media/") + Utils::fileNameForUrl(d->m_xmlUrl) + QLatin1String(".png");
     QFileInfo fileInfo(filename);
     QDir().mkpath(fileInfo.absolutePath());
-    d->imagePixmap.save(filename, "PNG");
+    d->m_imagePixmap.save(filename, "PNG");
     nodeModified();
 }
 
-Akregator::Feed::ArchiveMode Akregator::Feed::archiveMode() const
+Feed::ArchiveMode Feed::archiveMode() const
 {
-    return d->archiveMode;
+    return d->m_archiveMode;
 }
 
-void Akregator::Feed::setArchiveMode(ArchiveMode archiveMode)
+void Feed::setArchiveMode(ArchiveMode archiveMode)
 {
-    d->archiveMode = archiveMode;
+    d->m_archiveMode = archiveMode;
 }
 
-int Akregator::Feed::unread() const
+int Feed::unread() const
 {
-    return d->archive ? d->archive->unread() : 0;
+    return d->m_archive ? d->m_archive->unread() : 0;
 }
 
-void Akregator::Feed::setUnread(int unread)
+void Feed::setUnread(int unread)
 {
-    if (d->archive && unread != d->archive->unread()) {
-        d->archive->setUnread(unread);
+    if (d->m_archive && unread != d->m_archive->unread()) {
+        d->m_archive->setUnread(unread);
         nodeModified();
     }
 }
 
-void Akregator::Feed::setArticleDeleted(Article &a)
+void Feed::setArticleDeleted(Article &a)
 {
     d->setTotalCountDirty();
-    if (!d->deletedArticles.contains(a)) {
-        d->deletedArticles.append(a);
+    if (!d->m_deletedArticles.contains(a)) {
+        d->m_deletedArticles.append(a);
     }
 
-    d->updatedArticlesNotify.append(a);
+    d->m_updatedArticlesNotify.append(a);
     articlesModified();
 }
 
-void Akregator::Feed::setArticleChanged(Article &a, int oldStatus, bool process)
+void Feed::setArticleChanged(Article &a, int oldStatus, bool process)
 {
     int newStatus = a.status();
     if (oldStatus != -1) {
@@ -840,23 +851,23 @@ void Akregator::Feed::setArticleChanged(Article &a, int oldStatus, bool process)
             setUnread(unread() - 1);
         }
     }
-    d->updatedArticlesNotify.append(a);
+    d->m_updatedArticlesNotify.append(a);
     if (process) {
         articlesModified();
     }
 }
 
-int Akregator::Feed::totalCount() const
+int Feed::totalCount() const
 {
-    if (d->totalCount == -1) {
-        d->totalCount = std::count_if(d->articles.constBegin(), d->articles.constEnd(), [](const Article &art) -> bool {
+    if (d->m_totalCount == -1) {
+        d->m_totalCount = std::count_if(d->articles.constBegin(), d->articles.constEnd(), [](const Article &art) -> bool {
             return !art.isDeleted();
         });
     }
-    return d->totalCount;
+    return d->m_totalCount;
 }
 
-TreeNode *Akregator::Feed::next()
+TreeNode *Feed::next()
 {
     if (nextSibling()) {
         return nextSibling();
@@ -873,7 +884,7 @@ TreeNode *Akregator::Feed::next()
     return nullptr;
 }
 
-const TreeNode *Akregator::Feed::next() const
+const TreeNode *Feed::next() const
 {
     if (nextSibling()) {
         return nextSibling();
@@ -890,42 +901,42 @@ const TreeNode *Akregator::Feed::next() const
     return nullptr;
 }
 
-void Akregator::Feed::doArticleNotification()
+void Feed::doArticleNotification()
 {
-    if (!d->addedArticlesNotify.isEmpty()) {
+    if (!d->m_addedArticlesNotify.isEmpty()) {
         // copy list, otherwise the refcounting in Article::Private breaks for
         // some reason (causing segfaults)
-        QVector<Article> l = d->addedArticlesNotify;
+        QVector<Article> l = d->m_addedArticlesNotify;
         Q_EMIT signalArticlesAdded(this, l);
-        d->addedArticlesNotify.clear();
+        d->m_addedArticlesNotify.clear();
     }
-    if (!d->updatedArticlesNotify.isEmpty()) {
+    if (!d->m_updatedArticlesNotify.isEmpty()) {
         // copy list, otherwise the refcounting in Article::Private breaks for
         // some reason (causing segfaults)
-        QVector<Article> l = d->updatedArticlesNotify;
+        QVector<Article> l = d->m_updatedArticlesNotify;
         Q_EMIT signalArticlesUpdated(this, l);
-        d->updatedArticlesNotify.clear();
+        d->m_updatedArticlesNotify.clear();
     }
-    if (!d->removedArticlesNotify.isEmpty()) {
+    if (!d->m_removedArticlesNotify.isEmpty()) {
         // copy list, otherwise the refcounting in Article::Private breaks for
         // some reason (causing segfaults)
-        QVector<Article> l = d->removedArticlesNotify;
+        QVector<Article> l = d->m_removedArticlesNotify;
         Q_EMIT signalArticlesRemoved(this, l);
-        d->removedArticlesNotify.clear();
+        d->m_removedArticlesNotify.clear();
     }
     TreeNode::doArticleNotification();
 }
 
-void Akregator::Feed::enforceLimitArticleNumber()
+void Feed::enforceLimitArticleNumber()
 {
     int limit = -1;
-    if (d->archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleNumber) {
+    if (d->m_archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleNumber) {
         limit = Settings::maxArticleNumber();
-    } else if (d->archiveMode == limitArticleNumber) {
+    } else if (d->m_archiveMode == limitArticleNumber) {
         limit = maxArticleNumber();
     }
 
-    if (limit == -1 || limit >= d->articles.count() - d->deletedArticles.count()) {
+    if (limit == -1 || limit >= d->articles.count() - d->m_deletedArticles.count()) {
         return;
     }
 
