@@ -73,7 +73,7 @@ public:
     static QString archiveModeToString(ArchiveMode mode);
 
     /** creates a Feed object from a description in OPML format */
-    static Feed *fromOPML(QDomElement e, Akregator::Backend::Storage *storage);
+    static Feed *fromOPML(const QDomElement &e, Akregator::Backend::Storage *storage);
 
     /** default constructor */
     explicit Feed(Akregator::Backend::Storage *storage);
@@ -217,6 +217,8 @@ public:
 
     KJob *createMarkAsReadJob() override;
 
+    QString comment() const;
+    void setComment(const QString &comment);
 public Q_SLOTS:
     /** starts fetching */
     void fetch(bool followDiscovery = false);
