@@ -81,10 +81,7 @@ int Application::activate(const QStringList &args, const QString &workingDir)
 
 int main(int argc, char **argv)
 {
-    //Fix QtWebEngine + wayland
-#if defined(Q_OS_UNIX) && QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
-    qputenv("QT_QPA_PLATFORM", "xcb");
-#endif
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     Akregator::Application app(argc, &argv);
     KLocalizedString::setApplicationDomain("akregator");
